/***************************************************************************
 *   Copyright (C) 2006 by Julien Lemoine, Simon Viennot                   *
 *   lapinot@tuxfamily.org                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "widgetpopup.h"

#include <QLayout>
#include <QTextEdit>
#include <QPushButton>
#include <QFile>
#include <QTextStream>

//La fentre qui apparat quand on clique sur le menu "Licence" est diffrente des 4 autres fentres de ce type
//(elle possde deux boutons en plus), d'o le boolen "est_fenetre_licence" pour dterminer dans quel cas on se trouve
dlgPopup::dlgPopup( QWidget* parent, bool est_fenetre_licence ) : QDialog( parent) {
	//dfinition des polices de caractres
	QFont font_normal, font_monospace;
	font_normal.setFamily( "Bitstream Vera Sans" );
	font_monospace.setFamily( "Bitstream Vera Sans Mono" );
	
	#ifdef LINUX
		font_normal.setPointSize( 12 );
		font_monospace.setPointSize( 12 );
	#endif

	#ifdef WINDOWS
		font_normal.setPointSize( 10 );
		font_monospace.setPointSize( 10 );
	#endif
	
	//un layout vertical pour le QDialog dlgPopup
	vboxPopup = new QVBoxLayout( this );
	vboxPopup->setSpacing(0);
	vboxPopup->setMargin(0);
	
	//deux layouts horizontaux dans lesquels on placera le texte pour l'un, le ou les boutons pour l'autre
	horizontalLayout1 = new QWidget( this );
	horizontalLayout2 = new QWidget( this );
	hboxLayout1 = new QHBoxLayout(horizontalLayout1);
	hboxLayout2 = new QHBoxLayout(horizontalLayout2);
	
	hboxLayout1->setSpacing(0);
	hboxLayout1->setMargin(0);
	hboxLayout2->setSpacing(0);
	hboxLayout2->setMargin(0);
	
	vboxPopup->addWidget( horizontalLayout1 );
	vboxPopup->addWidget( horizontalLayout2 );
	
	//le cadre de texte
	textEditPopup = new QTextEdit( horizontalLayout1 );
	
	//la taille du texte, dont dpend la taille de la fentre au lancement
	#ifdef LINUX
		textEditPopup->setMinimumWidth(548);
	#endif
	
	#ifdef WINDOWS
		textEditPopup->setMinimumWidth(600);
	#endif
	textEditPopup->setMinimumHeight(313);
	
	//paramtres du texte
	textEditPopup->setReadOnly( TRUE );
	textEditPopup->setFont( font_monospace );
	
	hboxLayout1->addWidget(textEditPopup);
	
	//les boutons "Licence", "Traduction", que l'on affiche ou non suivant le cas
	if (est_fenetre_licence){
		pbLicence = new QPushButton( "Licence", horizontalLayout2 );
		pbLicence->setFont( font_normal );
		pbTraduction = new QPushButton( "Traduction", horizontalLayout2 );
		pbTraduction->setFont( font_normal );
		hboxLayout2->addStretch(1);
		hboxLayout2->addWidget(pbLicence);
		hboxLayout2->addStretch(1);
		hboxLayout2->addWidget(pbTraduction);
	}
	
	//le bouton "OK" que l'on affiche de toute faon
	pbOk = new QPushButton( "OK", horizontalLayout2 );
	pbOk->setFont( font_normal );
	hboxLayout2->addStretch(1);
	hboxLayout2->addWidget(pbOk);
	hboxLayout2->addStretch(1);
	
	//on ferme la fentre quand on clique sur "OK"
	connect( pbOk, SIGNAL( clicked() ), this, SLOT( close() ) );
	//fonctions reliant les boutons "Licence", "Traduction" et l'ouverture d'une nouvelle fentre.
	if(est_fenetre_licence){
		connect( pbLicence, SIGNAL( clicked() ), this, SLOT( ouvre_licence() ) );
		connect( pbTraduction, SIGNAL( clicked() ), this, SLOT( ouvre_traduction() ) );
	}
}

//fonction d'affichage d'une fentre contenant la GPL en anglais
//traduction ou non suivant boolen
void dlgPopup::ouvre_licence() {
	lire_texte(false);
}

//fonction d'affichage d'une fentre contenant la GPL en franais
void dlgPopup::ouvre_traduction() {
	lire_texte(true);
}

void dlgPopup::lire_texte(bool traduction) {
	dlgPopup glop( this, false );
	
	QString chGpl;
	if(traduction) {
		chGpl=QString(":/txt/gpl-fr.txt");
	} else {
		chGpl=QString(":/txt/gpl.txt");
	}
	QFile gpl( chGpl );
	gpl.open( QIODevice::ReadOnly );
	QTextStream gplstream( &gpl );
	glop.textEditPopup->setPlainText(gplstream.readAll());
	gpl.close();
	
	glop.exec();
}
